@@ -1,17 +1,16 @@
 import importlib
-from click.core import Command
-import click
+import asyncclick as click
 import os
 
+
 # all command entries
 @click.group()
-def entry():
+async def entry():
     pass
 
 
 # scan all functions in the package toolkit and find out the type of "command", then import these functions
 base_tools_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), "toolkit")
-# base_tools_path = "easy_toolkit/toolkit"
 base_module_name = "easy_toolkit.toolkit"
 
 
@@ -21,8 +20,7 @@ def scan_all_command(parent_path, module_name):
         if child.startswith("__"):
             continue
         if os.path.isdir(os.path.join(parent_path, child)):
-            ret.extend(scan_all_command(os.path.join(
-                parent_path, child), ".".join([module_name, child])))
+            ret.extend(scan_all_command(os.path.join(parent_path, child), ".".join([module_name, child])))
         else:
             if not child.endswith(".py"):
                 continue
@@ -41,6 +39,5 @@ for x in all_packages:
         if isinstance(f_obj, click.core.Command):
             entry.add_command(f_obj)
 
-
 if __name__ == '__main__':
-    entry()
+    entry(_anyio_backend="curio ")
